## 配置

ipu-cli 的初衷是提供尽量简洁高效的方式进行前端项目开发,所以大部分时候使用模板项目中的默认配置即可,但是为了满足不同的业务场景,也提供了灵活的配置入口方便自定义,配置文件都位于项目的 .ipu 目录下

.ipu 目录结构如下

```bash
|-- .ipu/
    |-- temp/   # 编译缓存目录
    |-- mock/   # 模拟数据接口服务配置
        |-- user.json  
        |-- ...
    |-- ipu.js    # 全局配置
    |-- entry.json # 项目模块设置
    |-- vendor.json # 项目第三方包依赖设置
```



### 项目配置

项目配置文件位于 `.ipu/ipu.js`,我们可以修改此配置文件来定制 `ipu` 



```js
module.exports = {
  type:"isomorphic",    /* 项目类型: `frontend`,`isomorphic` */
  spa:true            /* 是否单页面项目(SPA)? */
  jsExt:".js",    /* 入口 js 文件扩展名 */
  cssExt:".css",   /* 入口 css 文件扩展名 */
  distFolder: "dist",   /* 源码编译目标目录名称 */
  sourceFolder: "src",    /* 源码目录名称 */
  vendorFolder: "vendor",   /* 第三方依赖包编译目标目录名称 */
  assetFolder: "asset",    /* 静态资源目录名称 */
  fontFolder: "font",   /* 字体目录名称 */
  imageFolder: "image",    /* 图片目录名称 */
  beforeVendor(config){ return config }    /* `ipu vendor` 前置钩子函数 */
  afterVendor(err,stats){}     /* `ipu vendor` 后置钩子函数 */
  beforeDev(config){ return config }    /* `ipu dev` 前置钩子函数 */
  afterDev(err,stats){}     /* `ipu dev` 后置钩子函数 */
  beforeBuild(config){ return config }    /* `ipu build` 前置钩子函数 */
  afterBuild(err,stats){}     /* `ipu build` 后置钩子函数 */
  mock:".ipu/mock"	/* mock api 配置文件路径 */
}
```

 

### 构建依赖包配置

依赖包配置位于 `.ipu/vendor.json`,使用组合方式定义构建依赖包,比如下面我们使用 `base` 定义一个包含 `react` `react-dom` 的 js 依赖包组合,使用 `common` 定义一个包含 `fontawesome` `bootstrap` 的 css 依赖包组合,每个组合构建完毕后会生成一个组合名字对应的 js 或者 css 文件

  ```json
{
  "js":{
    "base":["react","react-dom"]     /* 定义一个JS依赖引用 */
  },
  "css":{
    "base":["font-awesome/css/font-awesome.css","bootstrap/dist/css/bootstrap.css"]     /* 定义一个css依赖引用 */
  }
}
  ```


### bundle 配置

模块配置位于 `.ipu/entry.json` ,键名为模块名,键值为模块配置对象

  ```json
{
  "index": {  /* 模块名称 */
    "input":{
      "js":"src/index.js" /* 入口 js 名 */
      "css":"src/index.css" /* 入口 css 名 */
      "html":"src/index.html" /* 入口 base 名 */
    }.
    "vendor": {"js": "base","css": "base"}   /* 模块依赖引用名称,引用自 `vendor.json` */
  },
  "user": {
    ...
  }
 }
  ```
### 模拟数据配置

模拟数据配置路径在 `.ipu/ipu.js`中定义

```js
module.exports = {
  mockConf:require('./mock/index.js')
}
```

依照上面配置的路径,在 `.ipu/mock/index.js` 中配置


  ```js
module.exports = [{
  "url": "/mock/user",    /* 接口请求 url */
  "method": "get",        /* 接口请求方法名称 */
  "response": {           /* 接口响应 */
    "code": 200,
    "data": {
      "id": 6,
      "name": "Mr.smith"
    }
  }
}] 
  ```


你也可以使用 [JSON Schema](http://json-schema.org) 一个更具语义化和持续化的模拟数据生成器来生成模拟数据

```json
[{
  "url": "/mock/users",
  "method": "get",   
  "response": {        
    "type": "object",
    "properties": {
      "id": {
        "$ref": "#/definitions/positiveInt"
      },
      "name": {
        "type": "string",
        "faker": "name.findName"
      },
    },
    "required": ["id", "name"],
    "definitions": {
      "positiveInt": {
        "type": "integer",
        "minimum": 0,
        "exclusiveMinimum": true
      }
    }
  }
},{
  "url": "/mock/user",
  "method": "post",
  "response": {
    "code": 200,
    "data": {
      "status": "ok"
    }
  }
}]
```



## 扩展

 `nva-core` `nva-task` `nva-server`  `nva-test`的三个子包可以独立安装使用

### nva-core 

基础webpack编译配置,满足一般的构建需求

```javascript
 import config from 'nva-core'
 const buildConfig = config(constants)
 webpack({
    ...buildConfig,
    entry:'index.js',
    output:{
      ...
    }
 }).run((err,stats)=>{ ... })
```
### nva-task

nva构建任务集合,可以根据需求自定义组合,接收 namespace 参数定义构建任务的命名空间

```javascript
var tasks = require('nva-tasks')({namespace:'nva'})
tasks.frontend.build() //前端项目构建
task.isomorphic.build()  //同构JS项目构建
```
### nva-server

基于connect的前端开发服务,带模拟数据接口功能

```javascript
import App from 'nva-server'
let app = App()
app.listen(3000,()=>{
  console.log('==> server stared at %d',3000)
})
```
也可以通过命令行方式调用

```bash
nva-server -p 5000 -P src
```



cli 配置参数说明:

|       参数名       |   默认值   |            说明            |
| :-------------: | :-----: | :----------------------: |
|  -v 或 —version  |    无    |           版本号            |
|  -c 或 --config  |    无    |          配置文件路径          |
|   -p 或 --port   |  3000   |           监听端口           |
| -m 或 —mock-path |    无    |         模拟数据配置路径         |
|   -P 或 —path    |    无    |         html资源路径         |
|   -A 或 —asset   |    无    |   css , js, png等静态资源路径   |
|   --rewrites    |    无    |          是否单页应用          |
|   -C 或 —cors    |    无    |         是否支持跨域调用         |
|   -L 或 --logs   |  false  |         是否启用请求日志         |
|  -b 或 —browser  | default | 默认打开的浏览器(使用 none 禁止自动打开) |
|  -i 或者 —index   |    无    |       index.html路径       |



### nva-test

基于 karma + mocha 的单元测试服务

运行测试

```bash
nva test
```

命令行参数

|     参数名      |  默认   |     描述     |
| :----------: | :----: | :----------: |
| -c or —-config |   无    |   测试配置    |

### nva-test-e2e

基于 nightwatch 的e2e测试服务

运行测试

```bash
nva test -r path/to/server.js -c path/to/config.js
```

命令行参数

|     参数名      |  默认   |     描述     |
| :----------: | :----: | :----------: |
| -c or —-config |   无    |    测试配置    |
| -r or —-runner |   无    |    应用测试服务器    |
| —-browser |   phantom.js    |    测试浏览器    |



## 贡献

欢迎各位在使用过程中发现问题及时通过issue反馈,或者提 PR 帮助我们,谢谢