let axios = require('axios')
let { resolve } = require('path')
let { differenceWith, map, isEqual, isEmpty, pickBy, keys } = require('lodash')
let chalk = require('chalk')
let inquirer = require("inquirer")
let execSync = require('execa').shellSync

module.exports = function(done, pkgs = [], forceUpdate) {
    if (pkgs.length === 0) {
        done()
    } else {
        let locals = {}
        pkgs.forEach(v => {
            let version
            try {
                version = require(resolve('node_modules', v, 'package.json')).version
                locals[v] = version
            } catch (e) {
                locals[v] = null
            }
        })
        axios.all(pkgs.map(v => axios.get(`https://registry.npm.taobao.org/${v}`, {timeout: 8000}))).then(rets => {
            let latest = {}
            rets.forEach(v => {
                if (v.status === 200) {
                    v = v.data
                    latest[v.name] = v['dist-tags'].latest
                }
            })

            if (isEmpty(latest)) {
                done()
            }
            if (isEqual(latest, locals)) {
                done()
            } else {
                let outdated = differenceWith(
                    map(latest, (v, k) => ({ name: k, version: v })),
                    map(locals, (v, k) => ({ name: k, version: v })),
                    (r1, r2) => r1.version === r2.version)
                let questions = outdated.map(v => ({
                    type: "confirm",
                    name: v.name,
                    message: chalk.yellow(`发现可升级的 ${v.name} 新版本: ${latest[v.name]} 当前版本: ${locals[v.name]}, 是否升级?`)
                }))
                let upgrade
                if (forceUpdate) {
                    upgrade = outdated.map(v=>`${v.name}@${latest[v.name]}`).join(' ')
                    try {
                        execSync(`npm i ${upgrade} -S`, { stdio: 'inherit' })
                    } catch (err) {
                        console.error(err)
                        process.exit(1)
                    }
                    done()
                } else {
                    inquirer.prompt(questions).then(answer => {
                        upgrade = keys(pickBy(answer, v => v === true)).map(v => `${v}@${latest[v]}`)
                        if (upgrade.length > 0) {
                            upgrade = upgrade.join(' ')
                            try {
                                execSync(`npm i ${upgrade} -S`, { stdio: 'inherit' })
                            } catch (err) {
                                console.error(err)
                                process.exit(1)
                            }
                        }
                        done()
                    })
                }
            }
        }).catch(() => {
            console.log(chalk.yellow('依赖包更新检测超时'))
            done()
        })
    }
}
