let axios = require('axios')
let semver = require('semver')
let chalk = require('chalk')
let inquirer = require("inquirer")
let execSync = require('execa').shellSync
let platform = require('os').platform()
let pkgJSON = require('../package.json')

module.exports = function(done, forceUpdate) {
    if (!semver.satisfies(process.version, pkgJSON.engines.node)) {
        console.log(chalk.red(
            '您的 nodeJS 版本必须满足: >=' + pkgJSON.engines.node + '.x'
        ))
        if (platform === 'darwin') {
            console.log(`推荐使用 ${chalk.cyan('https://github.com/creationix/nvm')} 升级和管理 nodeJS 版本`)
        } else if (platform === 'win32') {
            console.log(`推荐前往 ${chalk.cyan('https://nodejs.org/')} 下载 nodeJS 稳定版`)
        }
        process.exit(1)
    }

    axios.get('https://registry.npm.taobao.org/ipu-cli', {timeout: 8000}).then(function(ret) {
        if (ret.status === 200) {
            let latest = ret.data['dist-tags'].latest
            let local = pkgJSON.version
            if (semver.lt(local, latest)) {
                console.log(chalk.yellow('发现可升级的 ipu-cli 新版本.'))
                console.log('最新:    ' + chalk.green(latest))
                console.log('当前: ' + chalk.gray(local))
                if (forceUpdate) {
                    try {
                        execSync('npm i ipu-cli -g', { stdio: 'inherit' })
                        done()
                    } catch (err) {
                        console.error(err)
                        process.exit(1)
                    }
                } else {
                    inquirer.prompt([{
                        type: "confirm",
                        name: 'yes',
                        message: "是否立刻升级?"
                    }]).then(function(answer) {
                        if (answer.yes) {
                            try {
                                execSync('npm i ipu-cli -g', { stdio: 'inherit' })
                                done()
                            } catch (err) {
                                console.error(err)
                                process.exit(1)
                            }
                        } else {
                            done()
                        }
                    })
                }
            } else {
                done()
            }
        } else {
            done()
        }
    }).catch(function() {
        console.log(chalk.yellow('脚手架更新检测超时'))
        done()
    })
}
