let inquirer = require('inquirer')
let path = require('path')
let downloadGitRepo = require('download-git-repo')
let hooks = require('./hooks')
let chalk = require('chalk')
let execSync = require('child_process').execSync

function ask(questions, stop, cb) {
    inquirer.prompt(questions).then(function(answers) {
        if (answers[stop]) {
            cb(answers)
        } else {
            ask(questions)
        }
    })
}

function download(repo, destPath) {
    return new Promise(function(resolve, reject) {
        downloadGitRepo(repo, destPath, function(err) {
            if (err) reject(err)
            resolve(true)
        })
    })
}

let options = {
    namespace: 'ipu',
    hooks,
    modConfPath: path.resolve('.ipu', 'entry.json'),
    favicon: path.join(__dirname,'..','asset','image','aid-favicon.png')
}

function switchMirror(mirror, useYarn = false) {
    let registry = ''
    let disturl = ''
    let client = useYarn ? 'yarn' : 'npm'
  
    if (['taobao', 'cnpm', 'nj', 'npm', 'aid'].includes(mirror) === false) {
      console.log(chalk.red('unsupported mirror'))
      process.exit(1)
    }
    switch (mirror) {
      case 'taobao':
        registry = 'https://registry.npm.taobao.org'
        disturl = 'https://npm.taobao.org/dist'
        break
      case 'cnpm':
        registry = 'http://r.cnpmjs.org'
        disturl = 'http://cnpmjs.org/dist'
        break
      case 'nj':
        registry = 'https://registry.nodejitsu.com'
        disturl = 'https://www.nodejitsu.com'
        break
      case 'npm':
        registry = 'https://registry.npmjs.org'
        disturl = 'https://npmjs.org/dist'
        break
      case 'aid':
        registry = 'http://10.1.241.35:4873/'
        // disturl = 'http://10.1.241.35:4873/dist'
        break
      default:
        break
    }
    try {
      execSync(`${client} config set registry ${registry}`, {
        stdio: 'inherit'
      })
      execSync(`${client} config set disturl ${disturl}`, {
        stdio: 'inherit'
      })
      console.log('')
      console.log(chalk.yellow(`  ${client}'s registry has set to ${registry}`))
      console.log('')
    } catch (err) {
      console.log(err)
      process.exit(1)
    }
  }

module.exports = {
    switchMirror,
    ask,
    download,
    options
}