let fs = require('fs')
let chalk = require('chalk')
let hooks = require('./hooks')
let path = require('path')

function loadConf(path, onError) {
    let conf = {}
    if (!fs.existsSync(path)) {
        console.log(chalk.red(`${path} not exist`))
        process.exit(1)
    }
    try {
        conf = require(path)
    } catch (e) {
        onError(e)
    }
    return conf
}

module.exports = function(options = {}) {
    const namespace = options.namespace ? options.namespace : 'ipu'
    const rootPath = `.${namespace}`
    const projConfPath = options.projConfPath ? options.projConfPath : path.resolve(rootPath, `${namespace}.js`)

    let proj = loadConf(projConfPath, () => {
        console.log(chalk.red('project config is invalid'))
        process.exit(1)
    })
    proj.default && (proj = proj.default)
    proj.selfcheck = true

    return {
        namespace,
        hooks,
        modConfPath: path.resolve('.ipu', 'entry.json'),
        vendorConfPath: process.env.NODE_ENV === 'production' ? path.resolve('.ipu', 'vendor.json') : fs.existsSync(path.resolve('.ipu', 'vendor.dev.json')) ? path.resolve('.ipu', 'vendor.dev.json') : path.resolve('.ipu', 'vendor.json'),
        favicon: path.join(__dirname, '..', 'asset', 'image', 'aid-favicon.png'),
        rootPath,
        projConfPath,
        proj
    }
}